#! /bin/bash

PACKAGE_NAME="printer-driver-bisheng-sharp-mx-2018uc-pcl6"
PACKAGE_VERSION="2.0.4"
PRINTER_NAME=( "SHARP MX-2018UC PCL6" "SHARP MX-2318UC PCL6" "SHARP MX-3128UC PCL6" "SHARP MX-2618NC PCL6" "SHARP MX-3118NC PCL6" "SHARP MX-3618NC PCL6" "SHARP MX-4128NC PCL6" "SHARP MX-5128NC PCL6" "SHARP MX-M2608U PCL6" "SHARP MX-M3108U PCL6" "SHARP MX-M3508U PCL6" "SHARP MX-M2608N PCL6" "SHARP MX-M3108N PCL6" "SHARP MX-M3508N PCL6" "SHARP MX-2638NC PCL6" "SHARP MX-3138NC PCL6" "SHARP MX-2338NC PCL6" "SHARP MX-2648NC PCL6" "SHARP MX-3148NC PCL6" "SHARP MX-3648NC PCL6" "SHARP MX-M3658N PCL6" "SHARP MX-M4658N PCL6" "SHARP MX-M5658N PCL6" "SHARP MX-M3608N PCL6" "SHARP MX-M4608N PCL6" "SHARP MX-M5608N PCL6" "SHARP MX-4148NC PCL6" "SHARP MX-5148NC PCL6" "SHARP DX-2008UC PCL6" "SHARP DX-2508NC PCL6" "SHARP MX-B4621R PCL6" "SHARP MX-B5621R PCL6" )

CONTAINER_PATH="$HOME/.deepinwine/$PACKAGE_NAME"
OPT_PATH="/opt/deepinwine/printer_drv/$PACKAGE_NAME"
WINEBIN="bisheng"
REGDIR="reg"
FILEDIR="files"

PRINTER_C=$1
found=0
for name in "${PRINTER_NAME[@]}"; do
    if [ "$PRINTER_C" = "$name" ]; then
        found=1
        break
    fi
done

if [ $found -eq 0 ]; then
    echo "printer $PRINTER_C not found"
    exit 0
fi

if [ -z "$PACKAGE_NAME" -o ! -d "$OPT_PATH" ]; then
    exit 1
fi

if [ -d "$CONTAINER_PATH" ]; then
    # compare version
    if [ ! -f "$CONTAINER_PATH/VERSION" ] || [ "$(cat "$CONTAINER_PATH/VERSION")" != "$PACKAGE_VERSION" ]; then
        rm -rf "$CONTAINER_PATH"
    fi
fi

WININI="$CONTAINER_PATH/drive_c/windows/win.ini"
if [ -f  $WININI ]; then
    grep -q "^$PRINTER_C=winerp.drv,USB" "$WININI" && exit 0
fi

if [ -d "$OPT_PATH/$REGDIR" ]; then
    find "$OPT_PATH/$REGDIR" -type f -regex ".*\.reg" | while read file; do
        WINEPREFIX=$CONTAINER_PATH $WINEBIN regedit "$file"
    done
fi

if [ -d "$OPT_PATH/$FILEDIR" ]; then
    find "$OPT_PATH/$FILEDIR" -not -type d | while read file; do
        path="$CONTAINER_PATH/drive_c/${file#*$FILEDIR/}"
        dir="${path%/*}"
        mkdir -p "$dir"
        cp -d "$file" "$path"
    done
fi

if [ -f "$WININI" ]; then
    grep -q "^\[devices\]" "$WININI" || sed -i -e "$ a [devices]" "$WININI"
    grep -q "^\[PrinterPorts\]" "$WININI" || sed -i -e "$ a [PrinterPorts]" "$WININI"
    sed -i -e "/^\[devices\]/a $PRINTER_C=winerp.drv,USB" "$WININI"
    sed -i -e "/^\[PrinterPorts\]/a $PRINTER_C=winerp.drv,USB,15,45" "$WININI"
fi

WINESERVER_RUNNING=1
WINESERVER_FINDNUM=0
while [ $WINESERVER_RUNNING -eq 1 ]
do
        WINESERVER_PATH=`ps -aux|grep wineserver|grep -v grep`
        if [ "$WINESERVER_PATH" = "" ] || [ $WINESERVER_FINDNUM -eq 3 ]; then
                WINESERVER_RUNNING=0
        else
                let WINESERVER_FINDNUM+=1
                sleep 1
        fi
done

echo "$PACKAGE_VERSION" > "$CONTAINER_PATH/VERSION"
echo "$PRINTER_NAME" > "$CONTAINER_PATH/name.log"
